@@ -44,7 +44,7 @@ class Text(Element):
     #:
     #:    It currently does not support ``'xhtml'``.
     type = Attribute('type', Enum(['text', 'html']),
-                     required=True, default='text')
+                     required=True, default=lambda _: 'text')
 
     #: (:class:`str`) The content of the text.  Interpretation for this
     #: has to differ according to its :attr:`type`.  It corresponds to
@@ -168,7 +168,7 @@ class Link(Element):
 
     #: (:class:`str`) The relation type of the link.  It corresponds to
     #: ``rel`` attribute of :rfc:`4287#section-4.2.7.2` (section 4.2.7.2).
-    relation = Attribute('rel', default='alternate')
+    relation = Attribute('rel', default=lambda _: 'alternate')
 
     #: (:class:`str`) The optional hint for the MIME media type of the linked
     #: content.  It corresponds to ``type`` attribute of
@@ -205,6 +205,21 @@ class Link(Element):
         return hash((self.uri, self.relation, self.mimetype, self.language,
                      self.title, self.byte_size))
 
+    @property
+    def html(self):
+        """(:class:`bool`) Whether its :attr:`mimetype` is HTML (or XHTML).
+
+        .. versionadded:: 0.2.0
+
+        """
+        if self.mimetype:
+            match = re.match(r'^\s*([^;/\s]+/[^;/\s]+)\s*(?:;\s*.*)?$',
+                             self.mimetype)
+            if match:
+                mimetype = match.group(1)
+                return mimetype in ('text/html', 'application/xhtml+xml')
+        return False
+
     def __unicode__(self):
         return self.uri
 
@@ -266,6 +281,28 @@ class LinkList(collections.MutableSequence):
             )
         return LinkList.list_type(l for l in self if l.mimetype == pattern)
 
+    @property
+    def permalink(self):
+        """(:class:`Link`) Find the permalink from the list.  The following
+        list shows precedence of lookup conditions:
+
+        1. :attr:`~Link.html`, and :attr:`~Link.relation` is ``'alternate'``
+        2. :attr:`~Link.html`
+        3. :attr:`~Link.relation` is ``'alternate'``
+        4. No permalink: return :const:`None`
+
+        .. versionadded:: 0.2.0
+
+        """
+        links = [(lnk, (lnk.html, lnk.relation == 'alternate')) for lnk in self]
+        filterred_links = [(l, cond) for l, cond in links if cond[0] or cond[1]]
+        try:
+            link, _ = max(filterred_links, key=lambda pair: pair[1])
+        except ValueError:
+            pass
+        else:
+            return link
+
 
 # FIXME: it probably would be common for all specialized element list types
 LinkList.list_type = type('LinkList.list_type', (list, LinkList), {})
@@ -297,6 +334,14 @@ class Category(Element):
     #: :rfc:`4287#section-4.2.2.3` (section 4.2.2.3).
     label = Attribute('label')
 
+    def __entity_id__(self):
+        return self.term
+
+    def __merge_entities__(self, other):
+        if not self.label:
+            self.label = other.label
+        return self
+
     def __unicode__(self):
         return self.label or self.term
 
