@@ -82,6 +82,8 @@ def rss_get_channel_data(root, feed_url):
     crawler_hints = {}
     contributors = []
     for data in root:
+        if not data.text:
+            _log.warn('Empty tag: %s', data)
         if data.tag == 'title':
             feed_data.title = Text(value=data.text or '')
         elif data.tag == 'link':
@@ -142,7 +144,7 @@ def rss_get_item_data(entries):
             elif data.tag == 'category':
                 entry_data.categories = [Category(term=data.text)]
             elif data.tag == 'comments':
-                #entry_data['comments'] = data.text
+                # entry_data['comments'] = data.text
                 pass  # FIXME
             elif data.tag == 'enclosure':
                 link = Link(mimetype=data.get('type'), uri=data.get('url'))
